Package: QCAcluster
Type: Package
Title: Tools for the Analysis of Clustered Data in QCA
Version: 0.2.0
Authors@R: c(
  person(given = "Ingo", family = "Rohlfing", role = c("aut", "cre"),
  email = "ingo.rohlfing@uni-passau.de", 
  comment = c("0000-0001-8715-4771")),
  person(given = "Ayjeren", family = "Bekmuratovna", role = c("aut")),
  person(given = "Jan", family = "Schwalbach", 
  email = "jan.schwalbach@gesis.org", role = c("aut"),
  comment = c("0000-0002-6990-8098"))
  )
Depends: R (>= 2.10)
Description: Clustered set-relational data in Qualitative Comparative Analysis
    (QCA) can have a hierarchical structure, a panel structure or repeated cross
    sections. 'QCAcluster' allows researchers to supplement the analysis
    of pooled the data with a differentiated perspective focusing on selected 
    partitions of the data. The pooled data can be partitioned along the 
    dimensions of the clustered data (individual cross sections or time series) 
    to perform partition-specific truth table minimization. Empirical 
    researchers can further calculate the weight that each partition has on the 
    parameters of the pooled solution and the diversity of the cases under 
    analysis within and across partitions 
    (see <https://ingorohlfing.github.io/QCAcluster/>).
License: GPL-3
Encoding: UTF-8
LazyData: true
Imports: plyr (>= 1.8.5), QCA (>= 3.07), testit (>= 0.11), purrr (>=
        0.3.3), UpSetR (>= 1.4.0), magrittr, stringi (>= 1.7.4),
        rlist(>= 0.4.6.1)
URL: https://github.com/ingorohlfing/QCAcluster
BugReports: https://github.com/ingorohlfing/QCAcluster/issues
Suggests: rmarkdown, knitr
VignetteBuilder: knitr
Language: en-US
Config/roxygen2/version: 8.0.0
NeedsCompilation: no
Packaged: 2026-05-17 19:37:38 UTC; ingor
Author: Ingo Rohlfing [aut, cre] (0000-0001-8715-4771),
  Ayjeren Bekmuratovna [aut],
  Jan Schwalbach [aut] (0000-0002-6990-8098)
Maintainer: Ingo Rohlfing <ingo.rohlfing@uni-passau.de>
Repository: CRAN
Date/Publication: 2026-05-23 12:30:07 UTC
Built: R 4.6.0; ; 2026-05-25 03:38:03 UTC; unix
