# Generated by roxygen2: do not edit by hand

export(partition_div)
export(partition_min)
export(partition_min_inter)
export(upset_conditions)
export(upset_configurations)
export(wop)
export(wop_inter)
import(QCA)
import(UpSetR)
importFrom(magrittr,"%>%")
importFrom(plyr,ldply)
importFrom(purrr,map)
importFrom(rlist,list.flatten)
importFrom(stats,na.omit)
importFrom(stringi,stri_detect_fixed)
importFrom(stringi,stri_split_fixed)
importFrom(stringi,stri_trim)
importFrom(stringi,stri_unique)
importFrom(testit,has_error)
