QCACluster

## Contributors

Three people have contributed to `QCAcluster`. In alphabetical order:

-   Ayjeren Bekmuratnova R. [(Github)](https://github.com/AyjerenR/)
-   Ingo Rohlfing [(Github)](https://github.com/ingorohlfing)
-   Jan Schwalbach [(Github)](https://github.com/JanSchwalbach)

## Description of package

Clustered data can take different forms in empirical research. The data
might have a hierarchical structure (lower-level units nested in
higher-level units); we might have multiple units nested in time (panel
data); or the combination of both. The R package `QCAcluster` includes
multiple tools for the analysis of clustered data in *Qualitative
Comparative Analysis*. The use of the tools promises insights that would
go unnoticed in a pooled analysis ignoring the clusters in the data.

Version 0.2.0 of the package is on Github. This version is not on CRAN yet, but 
should be soon. 

``` r
pak::pak("ingorohlfing/QCAcluster")
```

------------------------------------------------------------------------

Work on the package was funded by the European Research Council (ERC)
under the European Union’s Horizon 2020 research and innovation program
(grant agreement number 638425, *Enhanced Qualitative and Multimethod
Research*).
